pub struct LuaEngineOptions {
pub pool_config: LuaVmPoolConfig,
pub host_options: LuaRuntimeHostOptions,
}Expand description
Construction options used by the host to create one LuaSkills runtime engine. 宿主创建单个 LuaSkills 运行时引擎时使用的构造选项。
Fields
pool_config: LuaVmPoolConfigPool sizing configuration for reusable Lua virtual machines. 可复用 Lua 虚拟机池的容量配置。
host_options: LuaRuntimeHostOptionsHost-owned runtime paths and external library locations. 宿主拥有的运行时路径与外部动态库位置配置。
Implementations
Sourceimpl LuaEngineOptions
impl LuaEngineOptions
Sourcepub fn new(
pool_config: LuaVmPoolConfig,
host_options: LuaRuntimeHostOptions,
) -> Self
pub fn new( pool_config: LuaVmPoolConfig, host_options: LuaRuntimeHostOptions, ) -> Self
Build engine options from one pool config and one host option object. 基于一份虚拟机池配置和一份宿主选项对象构造引擎选项。